<?php

if (!function_exists('curly_mkdf_footer_options_map')) {
    function curly_mkdf_footer_options_map() {

        curly_mkdf_add_admin_page(
            array(
                'slug' => '_footer_page',
                'title' => esc_html__('Footer', 'curly'),
                'icon' => 'fa fa-sort-amount-asc'
            )
        );

        $footer_panel = curly_mkdf_add_admin_panel(
            array(
                'title' => esc_html__('Footer', 'curly'),
                'name' => 'footer',
                'page' => '_footer_page'
            )
        );

        curly_mkdf_add_admin_field(
            array(
                'type' => 'yesno',
                'name' => 'footer_in_grid',
                'default_value' => 'yes',
                'label' => esc_html__('Footer in Grid', 'curly'),
                'description' => esc_html__('Enabling this option will place Footer content in grid', 'curly'),
                'parent' => $footer_panel
            )
        );

        curly_mkdf_add_admin_field(
            array(
                'type' => 'yesno',
                'name' => 'uncovering_footer',
                'default_value' => 'no',
                'label' => esc_html__('Uncovering Footer', 'curly'),
                'description' => esc_html__('Enabling this option will make Footer gradually appear on scroll', 'curly'),
                'parent' => $footer_panel,
            )
        );

        curly_mkdf_add_admin_field(
            array(
                'type' => 'yesno',
                'name' => 'show_footer_top',
                'default_value' => 'yes',
                'label' => esc_html__('Show Footer Top', 'curly'),
                'description' => esc_html__('Enabling this option will show Footer Top area', 'curly'),
                'parent' => $footer_panel,
            )
        );

        $show_footer_top_container = curly_mkdf_add_admin_container(
            array(
                'name' => 'show_footer_top_container',
                'parent' => $footer_panel,
                'dependency' => array(
                    'show' => array(
                        'show_footer_top' => 'yes'
                    )
                )
            )
        );

        curly_mkdf_add_admin_field(
            array(
                'type' => 'select',
                'name' => 'footer_top_columns',
                'parent' => $show_footer_top_container,
                'default_value' => '3 3 3 3',
                'label' => esc_html__('Footer Top Columns', 'curly'),
                'description' => esc_html__('Choose number of columns for Footer Top area', 'curly'),
                'options' => array(
                    '12' => '1',
                    '6 6' => '2',
                    '4 4 4' => '3',
                    '3 3 6' => '3 (25% + 25% + 50%)',
                    '3 3 3 3' => '4'
                )
            )
        );

        curly_mkdf_add_admin_field(
            array(
                'type' => 'select',
                'name' => 'footer_top_columns_alignment',
                'default_value' => 'left',
                'label' => esc_html__('Footer Top Columns Alignment', 'curly'),
                'description' => esc_html__('Text Alignment in Footer Columns', 'curly'),
                'options' => array(
                    '' => esc_html__('Default', 'curly'),
                    'left' => esc_html__('Left', 'curly'),
                    'center' => esc_html__('Center', 'curly'),
                    'right' => esc_html__('Right', 'curly')
                ),
                'parent' => $show_footer_top_container,
            )
        );

        curly_mkdf_add_admin_field(
            array(
                'name' => 'footer_top_background_color',
                'type' => 'color',
                'label' => esc_html__('Background Color', 'curly'),
                'description' => esc_html__('Set background color for top footer area', 'curly'),
                'parent' => $show_footer_top_container
            )
        );

        curly_mkdf_add_admin_field(
            array(
                'type' => 'yesno',
                'name' => 'show_footer_bottom',
                'default_value' => 'yes',
                'label' => esc_html__('Show Footer Bottom', 'curly'),
                'description' => esc_html__('Enabling this option will show Footer Bottom area', 'curly'),
                'parent' => $footer_panel,
            )
        );

        $show_footer_bottom_container = curly_mkdf_add_admin_container(
            array(
                'name' => 'show_footer_bottom_container',
                'parent' => $footer_panel,
                'dependency' => array(
                    'show' => array(
                        'show_footer_bottom' => 'yes'
                    )
                )
            )
        );

        curly_mkdf_add_admin_field(
            array(
                'type' => 'select',
                'name' => 'footer_bottom_columns',
                'default_value' => '6 6',
                'label' => esc_html__('Footer Bottom Columns', 'curly'),
                'description' => esc_html__('Choose number of columns for Footer Bottom area', 'curly'),
                'options' => array(
                    '12' => '1',
                    '6 6' => '2',
                    '4 4 4' => '3'
                ),
                'parent' => $show_footer_bottom_container,
            )
        );

        curly_mkdf_add_admin_field(
            array(
                'name' => 'footer_bottom_background_color',
                'type' => 'color',
                'label' => esc_html__('Background Color', 'curly'),
                'description' => esc_html__('Set background color for bottom footer area', 'curly'),
                'parent' => $show_footer_bottom_container
            )
        );
    }

    add_action('curly_mkdf_options_map', 'curly_mkdf_footer_options_map', 11);
}